.right-aligned {
  text-align: right;
}

.center-aligned {
  text-align: center;
}

.left-aligned {
  text-align: left;
}

#table-pagination {
  text-align: center;
  margin: 20px;
}

table {
  border-spacing: 0;
  margin: auto;
  max-width: 920px;
}

tr {
  height: 20px;
}

tr.data-row:hover {
  background-color: rgb(51, 51, 68);
  color: white;
  cursor: pointer;
}

td {
  padding: 5px;
  padding-left: 20px;
  padding-right: 20px;
}

th {
  height: 40px;
  padding-left: 20px;
  padding-right: 20px;
}

#table-div {
  width: 100%;
  margin-top: 40px;
}

#table-pagination div {
  padding: 5px;
}
