pre {
  width: 100%;
  height: 100%;
  margin: 0;
  padding: 0;
  background-color: white !important;
  white-space: pre-wrap; /* css-3 */
  white-space: -moz-pre-wrap; /* Mozilla, since 1999 */
  /*noinspection CssInvalidElement*/
  white-space: -pre-wrap; /* Opera 4-6 */
  white-space: -o-pre-wrap; /* Opera 7 */
  word-wrap: break-word; /* Internet Explorer 5.5+ */
}

code {
  font-family: Fantasque;
  background-color: white !important;
  width: 100% !important;
  height: auto;
  padding: 0 !important;
}

body {
  margin: 0;
  padding: 0;
}

html {
  margin: 0;
  padding: 0;
}
