# Generated by Django 3.2.16 on 2022-10-28 08:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example_app', '0002_alter_blind_photo'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='blind',
            constraint=models.UniqueConstraint(condition=models.Q(('name', ''), _negated=True), fields=('name',), name='unique_name_if_provided'),
        ),
    ]
